@@ -1,6 +1,6 @@
 #compute composite loss function cfun(z), where z is the value computed from convex function dfun
 compute_g <- function(z, cfun, s, delta=0.0001){
-    if(is.null(s)) s <- assign_s(cfun, z) else check_s(cfun, s)
+    if(is.null(s)) s <- assign_s(cfun, z) else check_s(cfun, dfun=1, s) #for now forget about dfun
     if(cfun==6)
            if(s > 1) delta <- (s-1)/2 else
            if(s==1) delta <- 0 else{
