@@ -3,7 +3,7 @@
 #outpu: updated weights
 ### this is different from R/update_wt in that the inputs are different 
 compute_wt <- function(z, weights, cfun, s, delta=0.0001){
-    if(is.null(s)) s <- assign_s(cfun, z) else check_s(cfun, s)
+    if(is.null(s)) s <- assign_s(cfun, z) else check_s(cfun, dfun=1, s) #for now forget about dfun
     if(missing(weights)) weights <- rep(1, length(z))
     if(cfun==6)
            if(s > 1) delta <- (s-1)/2 else
