@@ -1,4 +1,6 @@
-C     update the active set with only non-zero coefficients 
+C     update the active set with only non-zero coefficients
+C     input: m, beta, eps
+C     output: activeset, jk
       subroutine find_activeset(m, beta, eps, activeset, jk)
 
       implicit none
@@ -6,6 +8,10 @@ C     update the active set with only non-zero coefficients
       double precision beta(m), eps
 
 
+      do 90 j=1, m
+         activeset(j)=0
+90    continue
+      
 C     jk: number of variables in active set
       jk = 0
 C     it is possible, jk=0 if beta=0, like intercept-only
@@ -18,11 +24,5 @@ C     used jk not j, to be indexed in loop_gaussian subroutine
       endif
 60    continue
       
-      if(jk .EQ. 0)then
-      do 90 j=1, m
-         activeset(j)=0
-90    continue
-      endif
-      
       return
       end
