@@ -20,13 +20,15 @@ C     y
      +     wtold,trace,jj,rescale,converged,theta,pll,activeset, jk)
       implicit none
       integer trace, n, m, standardize, intercept, family, jj, i,j,
-     +     penalty, converged, rescale, interset(1),activeset(m), jk, ii
+     +     penalty, converged, rescale,activeset(m), jk, ii
       double precision x(n, m), y(n), thresh, eps,beta(m),beta_old(m) 
       double precision lambda(m), alpha, gam, wtold(n)
       double precision z(n), b0, b0_old, xd(m), yhat(n), w(n),
-     +     r(n),xwx,xwr, wtnew(n), wsum,mu(n), theta, pll_old, pll,
-     +     b0_ch(1), b0_old_ch(1)
+     +     r(n),xwx,xwr, wtnew(n), wsum,mu(n), theta, pll_old, pll
          
+      if(intercept .EQ. 0)then
+           b0 = 0
+      endif
       wsum = 0
       do i=1, n
          wsum = wsum + wtold(i)
@@ -129,22 +131,13 @@ C     check if beta(j) strictly increases penalized loglikehood function
          endif
 C     70: cycle through in the active set (end with endif statement) 
  40   continue
-      if(intercept .EQ. 1)then
-         interset(1)=1
-         b0_ch(1) = b0
-         b0_old_ch(1) = b0_old
-         call checkConvergence(1, b0_ch, b0_old_ch, eps, thresh, 
-     +        converged, interset, 1)      
-      endif
-      if(converged.EQ.1) then
-         call checkConvergence(m, beta, beta_old, eps, thresh, 
+      call checkConvergence(m, beta, beta_old, eps, thresh, 
      +        converged, activeset, jk)
-      endif    
 
       return
       end
 
-C     compute penalized log-likelihood value, this is only practical useful if rescale=FALSE
+C     compute penalized log-likelihood value, this is only practically useful if rescale=FALSE
       subroutine evalpll(y,x,n,m,beta,b0,family, theta, weights, alpha,
      +     gam,lambda, penalty, pll)     
       implicit none
